Module config

Module config 

Configuration types for the diff algorithm.

Structs

ArrayMatchConfig
Per-path configuration for array element matching.
DiffConfig
Top-level configuration for the diff algorithm.
MatchConfig
Configures how array elements are matched between actual and expected values.

Enums

AmbiguousMatchStrategy
Controls behavior when multiple actual array elements could match a single expected element.
ArrayMatchMode
How array elements are matched between actual and expected values at a given path.