pub struct MatchConfig { /* private fields */ }Expand description
Configures how array elements are matched between actual and expected values.
By default, arrays are matched by index. Each path can be configured with
a different matching mode and ambiguity strategy via ArrayMatchConfig.
Implementations
Sourceimpl MatchConfig
impl MatchConfig
Sourcepub fn with_config_at(self, path: &str, config: ArrayMatchConfig) -> Self
pub fn with_config_at(self, path: &str, config: ArrayMatchConfig) -> Self
Sets the array match configuration for the given dot-separated path.
Sourcepub fn config_at(&self, path: &str) -> Option<&ArrayMatchConfig>
pub fn config_at(&self, path: &str) -> Option<&ArrayMatchConfig>
Returns the array match configuration for the given path, if configured.