DiffNode

Enum DiffNode 

pub enum DiffNode {
    Container {
        segment: PathSegment,
        child_kind: ChildKind,
        omitted_count: u16,
        children: Vec<DiffNode>,
    },
    Leaf {
        segment: PathSegment,
        kind: DiffKind,
    },
}
A node in the diff tree.

Variants



Container

An intermediate node containing child diffs.

Fields

segment: PathSegment

The path segment for this container.

child_kind: ChildKind

Whether the children are object fields or array items.

omitted_count: u16

Number of siblings/elements in the actual data not shown in the diff.

children: Vec<DiffNode>

Child diff nodes.



Leaf

A terminal node representing a single difference.

Fields

segment: PathSegment

The path segment for this leaf.

kind: DiffKind

The kind of difference.

Implementations

Source

impl DiffNode

pub fn leaf(segment: PathSegment, kind: DiffKind) -> Self

Creates a leaf node representing a single difference.

pub fn container( segment: PathSegment, child_kind: ChildKind, omitted_count: u16, children: Vec<DiffNode>, ) -> Self

Creates a container node with child diffs.