pub struct DiffConfig { /* private fields */ }Expand description
Top-level configuration for the diff algorithm.
Implementations
Sourceimpl DiffConfig
impl DiffConfig
Sourcepub fn with_match_config(self, match_config: MatchConfig) -> Self
pub fn with_match_config(self, match_config: MatchConfig) -> Self
Sets the match config for array path lookups.
Sourcepub fn with_fallback_array_mode(self, mode: ArrayMatchMode) -> Self
pub fn with_fallback_array_mode(self, mode: ArrayMatchMode) -> Self
Sets the fallback array match mode for paths without explicit config.
Sourcepub fn with_fallback_ambiguous_strategy(
self,
strategy: AmbiguousMatchStrategy,
) -> Self
pub fn with_fallback_ambiguous_strategy( self, strategy: AmbiguousMatchStrategy, ) -> Self
Sets the fallback ambiguity strategy for paths without explicit config.
Sourcepub fn match_config(&self) -> &MatchConfig
pub fn match_config(&self) -> &MatchConfig
Returns the match config.
Sourcepub fn default_array_mode(&self) -> &ArrayMatchMode
pub fn default_array_mode(&self) -> &ArrayMatchMode
Returns the default array match mode.
Sourcepub fn default_ambiguous_strategy(&self) -> &AmbiguousMatchStrategy
pub fn default_ambiguous_strategy(&self) -> &AmbiguousMatchStrategy
Returns the default ambiguity strategy.