pub enum DiffKind {
Changed {
actual: Value,
expected: Value,
},
Missing {
expected: Value,
},
TypeMismatch {
actual: Value,
actual_type: &'static str,
expected: Value,
expected_type: &'static str,
},
}Expand description
The kind of difference found at a leaf node.
Variants
Changed
Values differ but have the same type.
Fields
Missing
A key or element is missing from the actual data.
TypeMismatch
Values have different JSON types.
Implementations