PathSegment

Enum PathSegment 

pub enum PathSegment {
    Key(String),
    NamedElement {
        match_key: String,
        match_value: String,
    },
    Index(u16),
    Unmatched,
}
A segment in the path to a diff location.

Variants



Key(String)

An object key (e.g. spec in spec.containers).



NamedElement

An array element matched by a distinguished key (e.g. name: FOO).

Fields

match_key: String

The key used to match (e.g. name).

match_value: String

The value of the match key (e.g. FOO).



Index(u16)

An array element matched by position.



Unmatched

An expected array element with no matching actual element.

Used with key-based and contains matching when no candidate was found in the actual array.

Implementations

Source

impl PathSegment

pub fn is_array(&self) -> bool

Returns true if this segment represents an array element.